==> haskell-yesod-static-1.6.1.0-330-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-yesod-static.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 yesod-static
version:              1.6.1.0
visibility:           public
id:                   yesod-static-1.6.1.0-FFCJ1SoL2e92EK7gF48KfE
key:                  yesod-static-1.6.1.0-FFCJ1SoL2e92EK7gF48KfE
license:              MIT
maintainer:
    Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>

author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/
synopsis:             Static file serving subsite for Yesod Web Framework.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-static>

category:             Web, Yesod
abi:                  0e819bc3b911335bf708211e0651b4b1
exposed:              True
exposed-modules:
    Yesod.EmbeddedStatic Yesod.EmbeddedStatic.Css.AbsoluteUrl
    Yesod.EmbeddedStatic.Generators Yesod.EmbeddedStatic.Types
    Yesod.Static

hidden-modules:
    Yesod.EmbeddedStatic.Internal Yesod.EmbeddedStatic.Css.Util

import-dirs:          /usr/lib/ghc-9.0.1/site-local/yesod-static-1.6.1.0
library-dirs:         /usr/lib/ghc-9.0.1/site-local/yesod-static-1.6.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/yesod-static-1.6.1.0
hs-libraries:         HSyesod-static-1.6.1.0-FFCJ1SoL2e92EK7gF48KfE
depends:
    async-2.2.3-JMLEcS5xCFd7RA7gdjgDSR
    attoparsec-0.14.1-HerROSs0hpLEq1E44JWFyp base-4.15.0.0
    base64-bytestring-1.2.1.0-5NkIB55dj355NkDWvSFElQ
    blaze-builder-0.4.2.2-Iw4q9HoGXXULmCBD2udQGP bytestring-0.10.12.1
    conduit-1.3.4.2-1UjnuMDsEIi5lhFydCbGRU containers-0.6.4.1
    cryptonite-0.29-7aXzWnn6dYq5HPWkX7eQFh
    cryptonite-conduit-0.2.2-CkFVJHp8rpNIx8BZpX1yTg
    css-text-0.1.3.0-5zq5InYMYF8KDo6Q3SvVpi
    data-default-0.7.1.1-5RJjHNv19ESJeD93LU2jRn directory-1.3.6.1
    file-embed-0.0.14.0-DpVDNlFaM0M9fTuZiTfuRf filepath-1.4.2.1
    hashable-1.3.3.0-Ob7F4bz7SrJSfcuDhkmwM
    hjsmin-0.2.0.4-4iQUPT0PP6KygG4LSMR6r
    http-types-0.12.3-FMJeXfXZe1F6BnXFIVUYKU
    memory-0.16.0-CGaPOmXCTce28vOCDDnDFr
    mime-types-0.1.0.9-5oy1hKbeK2pJX1lm5e9fjm process-1.6.11.0
    template-haskell-2.17.0.0 text-1.2.4.1 transformers-0.5.6.2
    unix-compat-0.5.3-CsWJk3UHZrh7lbWn5tdOhn
    unordered-containers-0.2.14.0-85xhml3fqIC6ZwgIEgRSE
    wai-3.2.3-DSH7BkNjh9i251bhFu9AmB
    wai-app-static-3.1.7.2-KR93JGMw18w3YFOXpycVfw
    yesod-core-1.6.21.0-3VryNGSUg7o1443nWIYjwY

haddock-interfaces:
    /usr/share/doc/haskell-yesod-static/html/yesod-static.haddock

haddock-html:         /usr/share/doc/haskell-yesod-static/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-yesod-static-1.6.1.0-331-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-yesod-static.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 yesod-static
version:              1.6.1.0
visibility:           public
id:                   yesod-static-1.6.1.0-7qC3IhhkFsAeBAt0Gsqg2
key:                  yesod-static-1.6.1.0-7qC3IhhkFsAeBAt0Gsqg2
license:              MIT
maintainer:
    Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>

author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/
synopsis:             Static file serving subsite for Yesod Web Framework.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-static>

category:             Web, Yesod
abi:                  fdeb4bdf8beca0cb29961fe2291c94bc
exposed:              True
exposed-modules:
    Yesod.EmbeddedStatic Yesod.EmbeddedStatic.Css.AbsoluteUrl
    Yesod.EmbeddedStatic.Generators Yesod.EmbeddedStatic.Types
    Yesod.Static

hidden-modules:
    Yesod.EmbeddedStatic.Internal Yesod.EmbeddedStatic.Css.Util

import-dirs:          /usr/lib/ghc-9.0.1/site-local/yesod-static-1.6.1.0
library-dirs:         /usr/lib/ghc-9.0.1/site-local/yesod-static-1.6.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/yesod-static-1.6.1.0
hs-libraries:         HSyesod-static-1.6.1.0-7qC3IhhkFsAeBAt0Gsqg2
depends:
    async-2.2.3-IdiNIvUG6Je7aMAPJeWE0D
    attoparsec-0.14.1-2NPvvgp5QbjKeCRmapAgpC base-4.15.0.0
    base64-bytestring-1.2.1.0-BH3if0BufO51UJ74fSwj5E
    blaze-builder-0.4.2.2-Iw4q9HoGXXULmCBD2udQGP bytestring-0.10.12.1
    conduit-1.3.4.2-AchFtERdZ63E4BSigaitpI containers-0.6.4.1
    cryptonite-0.29-19SjDRwWNox27CMfesQpq4
    cryptonite-conduit-0.2.2-8oA3ogBB9bA8OqaWRLJT9A
    css-text-0.1.3.0-DKXZ2XfjbUw620zAT6Kgyz
    data-default-0.7.1.1-J3rzpkFy8Zd5Q7EBzVOXXF directory-1.3.6.1
    file-embed-0.0.14.0-DpVDNlFaM0M9fTuZiTfuRf filepath-1.4.2.1
    hashable-1.3.4.0-6dnecuFViZBGFpHQwXe7GH
    hjsmin-0.2.0.4-r5sgLhkj248Qt5EB0sAFM
    http-types-0.12.3-5xSWCbzPZMJ3FKkHNvWW2m
    memory-0.16.0-CGaPOmXCTce28vOCDDnDFr
    mime-types-0.1.0.9-5oy1hKbeK2pJX1lm5e9fjm process-1.6.11.0
    template-haskell-2.17.0.0 text-1.2.4.1 transformers-0.5.6.2
    unix-compat-0.5.3-CsWJk3UHZrh7lbWn5tdOhn
    unordered-containers-0.2.14.0-FVdmWuNRiZiBPBGw5WvZRu
    wai-3.2.3-5Y0o3GgLhLBDIUVnFhg417
    wai-app-static-3.1.7.2-CRxLMEI9fIaBY1eJbhs7BQ
    yesod-core-1.6.21.0-GoIKtBx5FC8AplGzbSTCL0

haddock-interfaces:
    /usr/share/doc/haskell-yesod-static/html/yesod-static.haddock

haddock-html:         /usr/share/doc/haskell-yesod-static/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
